tlslite.constants.ContentType

Package tlslite :: Module constants :: Class ContentType |
[show private | hide private]
[frames | no frames]

## Class ContentType

Class Variable Summary
`int` | `alert` = 21
`tuple` | `all` = `(20, 21, 22, 23)`
`int` | `application_data` = 23
`int` | `change_cipher_spec` = 20
`int` | `handshake` = 22

Class Variable Details

    ### alert Type: `int` Value:
        21

    ### all Type: `tuple` Value:
        (20, 21, 22, 23)

    ### application_data Type: `int` Value:
        23

    ### change_cipher_spec Type: `int` Value:
        20

    ### handshake Type: `int` Value:
        22

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net